% Frame MATLAB Code with Moment Releases (Problem 7.6)
% Units: kips (k) and inches (in)
% Approach 2 - Remove all but one hinged members

clc     %Clear the window
clear   %Clear the memory

% This general format works well for most engineering problems
format short g

% Define the number of element dofs (always 6 for the frame element)
NEdof=6;

% Define the number of structural dofs
NSdof=3;

% Initialize {Pf} and [S]
P=zeros(NSdof,1);
Pf=zeros(NSdof,1);
S=zeros(NSdof,NSdof);

E=29000;

%Define nonzero terms in P

%P(1)=36;

% Define the code numbers
CodeNum=[
4 5 6  1  2  3
1 2 3  7  8  9] % Here we write out each row explicitly

% Define geometry and loading for each member, create the member stiffness and fixed-end-force vectors
% and then assemble {Pf} and [S]. Note that no units are shown, you just need to
% be consistent.

MemNum=1;
Qf1=zeros(NEdof,1);
A=10.3;
I=510;
LX=0;       % sign (+/-) important
LY=240;     % sign (+/-) important
L1=sqrt(LX^2+LY^2);

MT=2;   % 0 rigid; 1 b-hinge; 2 e-hinge; 3 hinged

            % Fixed End Forces/Moments 
W=40;       % Note: (+) Concentrated FORCE assumed down

FAb1=0;
FSb1=W/2;
FMb1=W*L1/8;
FAe1=0;
FSe1=W/2;
FMe1=-W*L1/8;

Qf1=[FAb1;FSb1;FMb1;FAe1;FSe1;FMe1]


[K1,Ff1,T1]=Create_TKF(E,I,A,LX,LY,MT,Qf1)
[S,Pf]=Assemble_S_Pf(S,K1,Pf,Ff1,MemNum,NEdof,NSdof,CodeNum);


MemNum=2;
Qf2=zeros(NEdof,1);
A=10.3;
I=510;
LX=360;     % sign (+/-) important
LY=0;       % sign (+/-) important
L2=sqrt(LX^2+LY^2);

MT=0;

            % Fixed End Forces/Moments 
w=1.5/12;   % Note: (+) Distributed FORCE assumed down

FAb2=0;
FSb2=w*L2/2;
FMb2=w*L2^2/12;
FAe2=0;
FSe2=w*L2/2;
FMe2=-w*L2^2/12;

Qf2=[FAb2;FSb2;FMb2;FAe2;FSe2;FMe2]


[K2,Ff2,T2]=Create_TKF(E,I,A,LX,LY,MT,Qf2)
[S,Pf]=Assemble_S_Pf(S,K2,Pf,Ff2,MemNum,NEdof,NSdof,CodeNum);


%***************** SOLVE *****************

% Solve for displacements (note the use of the backslash operator instead
% of the inv command. We could have used d=inv(S)*(P-Pf), or even
% d=S^-1*(P-Pf), but the backslash approach is much more efficient.)

P
Pf
S

d=S\(P-Pf)


%************** POST-PROCESS *************

% Use compatibility to create the {v} vectors for each element
v1=[0; 0; 0; d(1); d(2); 0];
v2=[d(1); d(2); d(3); 0; 0; 0];

u1=T1*v1;
u2=T2*v2

u1(6,1)=(3/(2*L1))*(-u1(2)+u1(5))-(1/2)*(u1(3))-(L1/(4*E*I))*FMe1;     % MT2

u1

% Calculate the member end forces (global)
F1=Ff1+K1*v1
F2=Ff2+K2*v2

% Calculate the member end forces (local)
Q1=T1*F1
Q2=T2*F2

% Calculate the support reactions
R4=F1(1)
R5=F1(2)
R6=F1(3)
R7=F2(4)
R8=F2(5)
R9=F2(6)    

